summaryrefslogtreecommitdiff
path: root/otk/eventhandler.hh
diff options
context:
space:
mode:
Diffstat (limited to 'otk/eventhandler.hh')
-rw-r--r--otk/eventhandler.hh11
1 files changed, 6 insertions, 5 deletions
diff --git a/otk/eventhandler.hh b/otk/eventhandler.hh
index 96bdff94..f2457568 100644
--- a/otk/eventhandler.hh
+++ b/otk/eventhandler.hh
@@ -1,3 +1,4 @@
+// -*- mode: C++; indent-tabs-mode: nil; c-basic-offset: 2; -*-
#ifndef __eventhandler__hh
#define __eventhandler__hh
@@ -16,7 +17,7 @@ extern "C" {
namespace otk {
-class OtkEventHandler {
+class EventHandler {
public:
//! Dispatches events to one of the other handlers based on their type.
virtual void handle(const XEvent &e);
@@ -134,14 +135,14 @@ public:
virtual void xkbHandler(const XkbEvent &) {}
#endif // XKB
- virtual ~OtkEventHandler();
+ virtual ~EventHandler();
protected:
- /*! Constructor for the OtkEventHandler class.
- This is protected so that OtkEventHandlers can't be instantiated on their
+ /*! Constructor for the EventHandler class.
+ This is protected so that EventHandlers can't be instantiated on their
own.
*/
- OtkEventHandler();
+ EventHandler();
private:
};